This is a supporting function that is used to calculate the log likelihood value at the nth iteration of theta.
tcensReg_llike(theta, y, X, a = -Inf, v = NULL)Numeric vector containing estimates of \(\beta\) and \(\log(\sigma)\)
Numeric vector with the observed truncated and censored outcomes
Numeric design matrix
Numeric scalar indicating the truncation value. Initial value is -Inf indicating no truncation
Numeric scalar indicating the censoring value. Initially set to NULL indicating no censoring
Scalar value of the log-likelihood at the nth iterate
If a and/or v are not specified then the corresponding censored only, truncated only,
or gaussian log likelihood will be used. This function is called as part of
the Newton-Raphson algorithm in tcensReg_newton and in additional
optimization methods in tcensReg_optim.